Sophie

Sophie

distrib > Fedora > 15 > i386 > by-pkgid > 1f2195038b87b91e7102d213eacdb51f > files > 7

kdepim-4.4.11.1-5.fc15.src.rpm

diff -up kdepim-4.4.5/cmake/modules/FindAssuan.cmake.libassuan1 kdepim-4.4.5/cmake/modules/FindAssuan.cmake
--- kdepim-4.4.5/cmake/modules/FindAssuan.cmake.libassuan1	2009-02-04 12:19:54.000000000 -0600
+++ kdepim-4.4.5/cmake/modules/FindAssuan.cmake	2010-08-11 13:56:02.663356542 -0500
@@ -48,7 +48,7 @@ include (MacroEnsureVersion)
 
 if ( WIN32 )
 
   # On Windows, we don't have a libassuan-config script, so we need to
   # look for the stuff ourselves:
 
   # in cmake, AND and OR have the same precedence, there's no
@@ -144,7 +144,7 @@ if ( WIN32 )
 
 else() # not WIN32
 
   # On *nix, we have the libassuan-config script which can tell us all we
   # need to know:
 
   # see WIN32 case for an explanation of what this does:
@@ -174,12 +174,12 @@ else() # not WIN32
     set( ASSUAN_PTHREAD_FOUND false )
     set( ASSUAN_PTH_FOUND     false )
 
-    find_program( _ASSUANCONFIG_EXECUTABLE NAMES libassuan-config )
+    find_program( _ASSUANCONFIG_EXECUTABLE NAMES libassuan1-config )
 
-    # if libassuan-config has been found
+    # if libassuan1-config has been found
     if ( _ASSUANCONFIG_EXECUTABLE )
       
-      message( STATUS "Found libassuan-config at ${_ASSUANCONFIG_EXECUTABLE}" )
+      message( STATUS "Found libassuan1-config at ${_ASSUANCONFIG_EXECUTABLE}" )
 
       exec_program( ${_ASSUANCONFIG_EXECUTABLE} ARGS --version OUTPUT_VARIABLE ASSUAN_VERSION )
@@ -48,7 +48,7 @@ include (MacroEnsureVersion)
 if ( WIN32 )
 
-  # On Windows, we don't have a libassuan-config script, so we need to
+  # On Windows, we don't have a libassuan1-config script, so we need to
   # look for the stuff ourselves:
 
@@ -144,7 +144,7 @@ if ( WIN32 )
 else() # not WIN32
 
-  # On *nix, we have the libassuan-config script which can tell us all we
+  # On *nix, we have the libassuan1-config script which can tell us all we
   # need to know:
 